| Portability | PatternGuards |
|---|---|
| Stability | provisional |
| Maintainer | nix-dev@cs.uu.nl |
Distribution.NixOS.Derivation.Cabal
Description
A represtation of Nix expressions based on Cabal builder defined in
pkgs/development/libraries/haskell/cabal/cabal.nix.
- data Derivation = MkDerivation {
- pname :: String
- version :: Version
- sha256 :: String
- isLibrary :: Bool
- isExecutable :: Bool
- buildDepends :: [String]
- buildTools :: [String]
- extraLibs :: [String]
- pkgConfDeps :: [String]
- configureFlags :: [String]
- cabalFlags :: FlagAssignment
- runHaddock :: Bool
- metaSection :: Meta
- parseDerivation :: String -> Maybe Derivation
- module Distribution.NixOS.Derivation.Meta
- module Data.Version
Documentation
data Derivation Source
A represtation of Nix expressions for building Haskell packages.
The data type correspond closely to the definition of
PackageDescription from Cabal.
Note that the Text instance definition provides pretty-printing, but no parsing as of now!
Constructors
| MkDerivation | |
Fields
| |
Instances
parseDerivation :: String -> Maybe DerivationSource
A very incomplete parser that extracts pname, version,
sha256, platforms, maintainers, and runHaddock from the given
Nix expression.
module Data.Version